==> assertables-4.2.0.crate: assertables-4.2.0/src/assert_command_stderr_contains_str.rs <==
/// Assert a command stderr string contains a given string.
///
/// * When true, return `()`.
///
/// * Otherwise, call [`panic!`] with a message and the values of the
///   expressions with their debug representations.
///
/// # Examples
///
/// ```rust
/// # #[macro_use] extern crate assertables;
/// # use std::panic;
/// use std::process::Command;
///
/// # fn main() {
/// let mut a = Command::new("printf");
/// assert_command_stderr_contains_str!(a, "usage");
/// //-> ()
///
/// # let result = panic::catch_unwind(|| {
/// let mut a = Command::new("printf");
/// assert_command_stderr_contains_str!(a, "abc");
/// //-> panic!("…")
/// // assertion failed: `assert_command_stderr_contains_str!(command, str)`
/// //  command program: `\"printf\"`,
/// //  str: `\"abc\"`
/// //  stderr: `\"usage: printf format [arguments ...]\\n\"`,
/// # });
/// # let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
/// # let expect = "assertion failed: `assert_command_stderr_contains_str!(command, str)`\n command program: `\"printf\"`,\n str: `\"abc\"`,\n stderr: `\"usage: printf format [arguments ...]\\n\"`";
/// # assert_eq!(actual, expect);
/// # }
/// ```
///
/// This macro has a second form where a custom message can be provided.
#[macro_export]
macro_rules! assert_command_stderr_contains_str {
    ($command:expr, $str:expr $(,)?) => ({
        let output = $ command.output();
        if output.is_err() {
            panic!("assertion failed: `assert_command_stderr_contains_str!(command, str)`\n command program: `{:?}`,\n str: `{:?}`,\n output: `{:?}`", $command.get_program(), $str, output)
        } else {
            let actual = String::from_utf8(output.unwrap().stderr).unwrap();
            if actual.contains($str) {
                ()
            } else {
                panic!("assertion failed: `assert_command_stderr_contains_str!(command, str)`\n command program: `{:?}`,\n str: `{:?}`,\n stderr: `{:?}`", $command.get_program(), $str, actual)
            }
        }
    });
    ($command:expr, $str:expr, $($arg:tt)+) => ({
        let output = $ command.output();
        if output.is_err() {
            panic!("{:?}", $($arg)+)
        } else {
            let actual = String::from_utf8(output.unwrap().stderr).unwrap();
            if actual.contains($str) {
                ()
            } else {
                panic!("{:?}", $($arg)+)
            }
        }
    });
}

#[cfg(test)]
mod tests {

    use std::process::Command;

    #[test]
    fn assert_command_stderr_contains_str_x_arity_2_success() {
        let mut a = Command::new("printf");
        let str = "usage";
        let x = assert_command_stderr_contains_str!(a, str);
        assert_eq!(x, ());
    }

    #[test]
    #[should_panic (expected = "assertion failed: `assert_command_stderr_contains_str!(command, str)`\n command program: `\"printf\"`,\n str: `\"abc\"`,\n stderr: `\"usage: printf format [arguments ...]\\n\"`")]
    fn assert_command_stderr_contains_str_x_arity_2_failure() {
        let mut a = Command::new("printf");
        let str = "abc";
        let _x = assert_command_stderr_contains_str!(a, str);
    }

    #[test]
    fn assert_command_stderr_contains_str_x_arity_3_success() {
        let mut a = Command::new("printf");
        let str = "usage";
        let x = assert_command_stderr_contains_str!(a, str, "message");
        assert_eq!(x, ());
    }

    #[test]
    #[should_panic (expected = "message")]
    fn assert_command_stderr_contains_str_x_arity_3_failure() {
        let mut a = Command::new("printf");
        let str = "abc";
        let _x = assert_command_stderr_contains_str!(a, str, "message");
    }

}

==> assertables-4.4.0.crate: assertables-4.4.0/src/assert_command_stderr_contains_str.rs <==
/// Assert a command stderr string contains a given string.
///
/// * When true, return `()`.
///
/// * Otherwise, call [`panic!`] with a message and the values of the
///   expressions with their debug representations.
///
/// # Examples
///
/// ```rust
/// # #[macro_use] extern crate assertables;
/// # use std::panic;
/// use std::process::Command;
///
/// # fn main() {
/// let mut a = Command::new("printf");
/// let str = "usage";
/// assert_command_stderr_contains_str!(a, str);
/// //-> ()
///
/// # let result = panic::catch_unwind(|| {
/// let mut a = Command::new("printf");
/// let str = "xyz";
/// assert_command_stderr_contains_str!(a, str);
/// //-> panic!("…")
/// // assertion failed: `assert_command_stderr_contains_str!(command, str)`
/// //  command program: `\"printf\"`,
/// //  str: `\"xyz\"`
/// //  stderr: `\"usage: printf format [arguments ...]\\n\"`,
/// # });
/// # let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
/// # let expect = "assertion failed: `assert_command_stderr_contains_str!(command, str)`\n command program: `\"printf\"`,\n str: `\"xyz\"`,\n stderr: `\"usage: printf format [arguments ...]\\n\"`";
/// # assert_eq!(actual, expect);
/// # }
/// ```
///
/// This macro has a second form where a custom message can be provided.
#[macro_export]
macro_rules! assert_command_stderr_contains_str {
    ($command:expr, $str:expr $(,)?) => ({
        let output = $ command.output();
        if output.is_err() {
            panic!("assertion failed: `assert_command_stderr_contains_str!(command, str)`\n command program: `{:?}`,\n str: `{:?}`,\n output: `{:?}`", $command.get_program(), $str, output)
        } else {
            let actual = String::from_utf8(output.unwrap().stderr).unwrap();
            if actual.contains($str) {
                ()
            } else {
                panic!("assertion failed: `assert_command_stderr_contains_str!(command, str)`\n command program: `{:?}`,\n str: `{:?}`,\n stderr: `{:?}`", $command.get_program(), $str, actual)
            }
        }
    });
    ($command:expr, $str:expr, $($arg:tt)+) => ({
        let output = $ command.output();
        if output.is_err() {
            panic!("{:?}", $($arg)+)
        } else {
            let actual = String::from_utf8(output.unwrap().stderr).unwrap();
            if actual.contains($str) {
                ()
            } else {
                panic!("{:?}", $($arg)+)
            }
        }
    });
}

#[cfg(test)]
mod tests {

    use std::process::Command;

    #[test]
    fn assert_command_stderr_contains_str_x_arity_2_success() {
        let mut a = Command::new("printf");
        let str = "usage";
        let x = assert_command_stderr_contains_str!(a, str);
        assert_eq!(x, ());
    }

    #[test]
    #[should_panic (expected = "assertion failed: `assert_command_stderr_contains_str!(command, str)`\n command program: `\"printf\"`,\n str: `\"xyz\"`,\n stderr: `\"usage: printf format [arguments ...]\\n\"`")]
    fn assert_command_stderr_contains_str_x_arity_2_failure() {
        let mut a = Command::new("printf");
        let str = "xyz";
        let _x = assert_command_stderr_contains_str!(a, str);
    }

    #[test]
    fn assert_command_stderr_contains_str_x_arity_3_success() {
        let mut a = Command::new("printf");
        let str = "usage";
        let x = assert_command_stderr_contains_str!(a, str, "message");
        assert_eq!(x, ());
    }

    #[test]
    #[should_panic (expected = "message")]
    fn assert_command_stderr_contains_str_x_arity_3_failure() {
        let mut a = Command::new("printf");
        let str = "xyz";
        let _x = assert_command_stderr_contains_str!(a, str, "message");
    }

}
